# cdf_apm_base

This module contains the data model configurations necessary for all Cognite Asset Performance
Management (APM) projects. The global data models pre-loaded in all CDF projects are
leveraged and extended by this module.

It is a requirement for both Infield, Maintain, and APM projects.